# Changelog

## 1.7.0 (2025-12-18)

Full Changelog: [v1.6.3...v1.7.0](https://github.com/Svahnar/svahnar-python/compare/v1.6.3...v1.7.0)

### Features

* **api:** api update ([9c66147](https://github.com/Svahnar/svahnar-python/commit/9c6614720c5deb3311dc113d12813ec2046f9b41))
* **api:** api update ([1ab6a45](https://github.com/Svahnar/svahnar-python/commit/1ab6a45d89df9dc3a2eef27a05bd7775b52482f6))
* **api:** api update ([82bd402](https://github.com/Svahnar/svahnar-python/commit/82bd402fca5bca23e085c86b7781dab7868f74f4))
* **api:** api update ([dce0896](https://github.com/Svahnar/svahnar-python/commit/dce08969c2d6be7eb1f0f9af35181e9b08ce3bf5))
* **api:** api update ([c9970df](https://github.com/Svahnar/svahnar-python/commit/c9970df554a45973d5e9f33672940097a905a73d))
* **api:** api update ([ee5e19f](https://github.com/Svahnar/svahnar-python/commit/ee5e19f93de383aec42faef34921743fcc88fe77))
* **api:** api update ([10f0a1b](https://github.com/Svahnar/svahnar-python/commit/10f0a1b69f686cd59cb7efcef5a150970e174406))
* **api:** api update ([eda1d26](https://github.com/Svahnar/svahnar-python/commit/eda1d26b56f3a2ec656d0ff5190b5e2791ec21e6))
* **api:** api update ([07920c8](https://github.com/Svahnar/svahnar-python/commit/07920c8d3c4ed29b626e7eb9f3208b7c878d1675))
* **client:** add support for aiohttp ([7b5d8c2](https://github.com/Svahnar/svahnar-python/commit/7b5d8c2f67d333ec155abac68971f447063d15a6))
* **client:** support file upload requests ([36de12b](https://github.com/Svahnar/svahnar-python/commit/36de12b25dde49185bc2425eaec7dfd6a8e3c354))


### Bug Fixes

* **ci:** correct conditional ([b1a0049](https://github.com/Svahnar/svahnar-python/commit/b1a0049ae01ec1ec24c5b18aa4d49ae869a8cc2c))
* **ci:** release-doctor — report correct token name ([b662a9d](https://github.com/Svahnar/svahnar-python/commit/b662a9db231d782441b7f1218c595e1ba3f6357c))
* **client:** correctly parse binary response | stream ([4437ed8](https://github.com/Svahnar/svahnar-python/commit/4437ed80248c7aa7ff1a46eda78e7b817df9f2c3))
* **client:** don't send Content-Type header on GET requests ([d878aa1](https://github.com/Svahnar/svahnar-python/commit/d878aa196a7e87b3b4075d16e6197e120250ed67))
* **parsing:** correctly handle nested discriminated unions ([4607e47](https://github.com/Svahnar/svahnar-python/commit/4607e47dc035338fde541b5c4b0fcffc314f9751))
* **parsing:** ignore empty metadata ([e2e5df9](https://github.com/Svahnar/svahnar-python/commit/e2e5df9f0239c4147e2d2153f8585e29717bec25))
* **parsing:** parse extra field types ([6008bd2](https://github.com/Svahnar/svahnar-python/commit/6008bd21eaba27b4b46065549b0c5a385c231163))
* **tests:** fix: tests which call HTTP endpoints directly with the example parameters ([8b013a9](https://github.com/Svahnar/svahnar-python/commit/8b013a9b52dffe9756841e60dad6e135cfd4cff8))


### Chores

* **ci:** change upload type ([78da907](https://github.com/Svahnar/svahnar-python/commit/78da90733f3b5a3b622664a1cd0bd959d9a191fb))
* **ci:** enable for pull requests ([19c1179](https://github.com/Svahnar/svahnar-python/commit/19c1179c2bfa2d1a74020594beedd6f8e608b95d))
* **ci:** only run for pushes and fork pull requests ([72e0f10](https://github.com/Svahnar/svahnar-python/commit/72e0f102b3d1e52922c2edea5d1415811f95c894))
* **internal:** add missing files argument to base client ([d3719c3](https://github.com/Svahnar/svahnar-python/commit/d3719c3ad3808a0d3ef6a9bc7817a67ada658861))
* **internal:** bump pinned h11 dep ([c21a35f](https://github.com/Svahnar/svahnar-python/commit/c21a35fe79f34d0fac4efe5ac3abfad877d5f37a))
* **internal:** codegen related update ([b312610](https://github.com/Svahnar/svahnar-python/commit/b31261080db71fe3f5ad22ec69b5fb065b9c6f82))
* **internal:** codegen related update ([8e4bd54](https://github.com/Svahnar/svahnar-python/commit/8e4bd544890576b35d7b320bdecccd8d882514ef))
* **internal:** codegen related update ([661b856](https://github.com/Svahnar/svahnar-python/commit/661b85675816fa1e31ec6bbda5aa33576a042498))
* **internal:** fix ruff target version ([1955b62](https://github.com/Svahnar/svahnar-python/commit/1955b62294d3884c30bfc4ce8e0fb0292ad8cf6d))
* **internal:** update conftest.py ([9eeb2eb](https://github.com/Svahnar/svahnar-python/commit/9eeb2ebae13d02ad2a3f6874032e0f80b65c5ab4))
* **package:** mark python 3.13 as supported ([a67f92a](https://github.com/Svahnar/svahnar-python/commit/a67f92afb6c7641655fecbd8701ea51a879f97a5))
* **project:** add settings file for vscode ([b869d29](https://github.com/Svahnar/svahnar-python/commit/b869d2944c019d2757b5b6b9104316bf925723f7))
* **readme:** fix version rendering on pypi ([c9cbe37](https://github.com/Svahnar/svahnar-python/commit/c9cbe377c666cf4ffabe95bc462be0fdb82b1a1a))
* **readme:** update badges ([8609971](https://github.com/Svahnar/svahnar-python/commit/8609971b1fa5fe41e628aa3f36af109d1809d504))
* **tests:** add tests for httpx client instantiation & proxies ([eedd563](https://github.com/Svahnar/svahnar-python/commit/eedd5635cb52f6e46511f4507be71b4a8b19ff0c))
* **tests:** run tests in parallel ([d8ace3e](https://github.com/Svahnar/svahnar-python/commit/d8ace3e3a83fdeebeb3211177abbcf72a061de6c))
* **tests:** skip some failing tests on the latest python versions ([8541fdc](https://github.com/Svahnar/svahnar-python/commit/8541fdcd5b492577c4440cee28b006644befa591))


### Documentation

* **client:** fix httpx.Timeout documentation reference ([874610f](https://github.com/Svahnar/svahnar-python/commit/874610f150c9250943ed3e2a58d3f396e2ba0f60))

## 1.6.3 (2025-06-09)

Full Changelog: [v1.6.2...v1.6.3](https://github.com/Svahnar/svahnar-python/compare/v1.6.2...v1.6.3)

### Features

* **api:** api update ([6335cda](https://github.com/Svahnar/svahnar-python/commit/6335cda983093170cbb13ffe83132903d4bddcb7))
* **client:** add follow_redirects request option ([e43906c](https://github.com/Svahnar/svahnar-python/commit/e43906cd67d964f8b14cf9f351193b3922fa1179))


### Bug Fixes

* **docs/api:** remove references to nonexistent types ([61619ee](https://github.com/Svahnar/svahnar-python/commit/61619eebecc05dff352a1300e3eab6af44d37f5c))
* **package:** support direct resource imports ([c2cf20d](https://github.com/Svahnar/svahnar-python/commit/c2cf20d11bd2e57175e8a4653bf3a9f61411a7b8))
* **pydantic v1:** more robust ModelField.annotation check ([161c228](https://github.com/Svahnar/svahnar-python/commit/161c228d12366f0be369cd7889a4f74ae2952f73))


### Chores

* broadly detect json family of content-type headers ([381bbec](https://github.com/Svahnar/svahnar-python/commit/381bbecdcb3c9627ef571d8c459de7c659fde4b2))
* **ci:** add timeout thresholds for CI jobs ([fe147ba](https://github.com/Svahnar/svahnar-python/commit/fe147ba121b2eec5939d52bb955dac348beddcef))
* **ci:** fix installation instructions ([6352602](https://github.com/Svahnar/svahnar-python/commit/6352602b66b2cb6da0fd5f5626b7cefc6e9be391))
* **ci:** only use depot for staging repos ([406c2a0](https://github.com/Svahnar/svahnar-python/commit/406c2a0b8750150c0db83b36eb3305a183ed25e1))
* **ci:** upload sdks to package manager ([1e8ccc0](https://github.com/Svahnar/svahnar-python/commit/1e8ccc07542134dcc808d54b9493e93a781ec48f))
* **client:** minor internal fixes ([d83ad2f](https://github.com/Svahnar/svahnar-python/commit/d83ad2fa93729ce55ff468907a87d522497c8c9b))
* configure new SDK language ([73d6aee](https://github.com/Svahnar/svahnar-python/commit/73d6aeec37b19d70a60a7803b6f192b8d4c4c037))
* **docs:** grammar improvements ([ca7f1c9](https://github.com/Svahnar/svahnar-python/commit/ca7f1c992fc5ae1ca723a5a0f0829a6752e4dc40))
* **docs:** remove reference to rye shell ([572d23f](https://github.com/Svahnar/svahnar-python/commit/572d23f0e63cbe43d5cb447de9d7a5462271af58))
* **internal:** avoid errors for isinstance checks on proxies ([898ef79](https://github.com/Svahnar/svahnar-python/commit/898ef797d2847d9fab76d3cfb866b84b6b7b40e0))
* **internal:** base client updates ([e0c7337](https://github.com/Svahnar/svahnar-python/commit/e0c733726325939b58083bc78d08a5585608e0f9))
* **internal:** bump pyright version ([9d6b518](https://github.com/Svahnar/svahnar-python/commit/9d6b518f2540325ad2e94a35230aa6dbf25070be))
* **internal:** codegen related update ([033da64](https://github.com/Svahnar/svahnar-python/commit/033da64c34f3049a394ba3c16f2d255c37f97246))
* **internal:** codegen related update ([ef83211](https://github.com/Svahnar/svahnar-python/commit/ef83211bde2560432cdc6ceec6849b3f88e87dfa))
* **internal:** fix list file params ([c281500](https://github.com/Svahnar/svahnar-python/commit/c281500a94291134c5b62d312e3c04b5487a0ac6))
* **internal:** import reformatting ([513b53e](https://github.com/Svahnar/svahnar-python/commit/513b53e41b4f0de5241165f88797a323d55962d5))
* **internal:** refactor retries to not use recursion ([5a8d385](https://github.com/Svahnar/svahnar-python/commit/5a8d38530b4ca21c7e6787d8421ca721053237f8))
* **internal:** update models test ([958a582](https://github.com/Svahnar/svahnar-python/commit/958a5824f9b472b093f2005f28c48209ffd06ac7))
* **internal:** update pyright settings ([3f2cf4b](https://github.com/Svahnar/svahnar-python/commit/3f2cf4ba117b151e9455982d1346550a8678655c))

## 1.6.2 (2025-04-12)

Full Changelog: [v1.6.1...v1.6.2](https://github.com/Svahnar/svahnar-python/compare/v1.6.1...v1.6.2)

### Features

* **api:** api update ([2a45e7a](https://github.com/Svahnar/svahnar-python/commit/2a45e7ae508c9ba5ae31c47a49b7679607aa752b))

## 1.6.1 (2025-04-12)

Full Changelog: [v1.6.0...v1.6.1](https://github.com/Svahnar/svahnar-python/compare/v1.6.0...v1.6.1)

### Features

* **api:** api update ([2e0720d](https://github.com/Svahnar/svahnar-python/commit/2e0720dfb06e045bb5b7698387132c4882a87e15))


### Bug Fixes

* **perf:** optimize some hot paths ([0ebdfe3](https://github.com/Svahnar/svahnar-python/commit/0ebdfe3e4cb33fff5d14267e5b794501ad5eb758))
* **perf:** skip traversing types for NotGiven values ([5d8817e](https://github.com/Svahnar/svahnar-python/commit/5d8817e30393fb3361c42eea1c4f2945d6c0bb9b))

## 1.6.0 (2025-04-11)

Full Changelog: [v1.5.0...v1.6.0](https://github.com/Svahnar/svahnar-python/compare/v1.5.0...v1.6.0)

### Features

* **api:** api update ([431c247](https://github.com/Svahnar/svahnar-python/commit/431c247dd21e0b73277d36470904a1e59c37bcec))

## 1.5.0 (2025-04-10)

Full Changelog: [v1.4.0...v1.5.0](https://github.com/Svahnar/svahnar-python/compare/v1.4.0...v1.5.0)

### Features

* **api:** api update ([cf7508d](https://github.com/Svahnar/svahnar-python/commit/cf7508d01894f7eb8fc97c52d8cd183e191c49c5))


### Chores

* **internal:** expand CI branch coverage ([492bd0f](https://github.com/Svahnar/svahnar-python/commit/492bd0f1d969a16534e4cd2e379c5c9e75f73041))
* **internal:** reduce CI branch coverage ([f666714](https://github.com/Svahnar/svahnar-python/commit/f666714ba48db9151b5f6fac0fc55318219a1483))

## 1.4.0 (2025-04-09)

Full Changelog: [v1.3.0...v1.4.0](https://github.com/Svahnar/svahnar-python/compare/v1.3.0...v1.4.0)

### Features

* **api:** api update ([#21](https://github.com/Svahnar/svahnar-python/issues/21)) ([2feec6d](https://github.com/Svahnar/svahnar-python/commit/2feec6d5ce4cbba891f9bdd2d7bcbab4e9b41428))

## 1.3.0 (2025-04-09)

Full Changelog: [v1.2.0...v1.3.0](https://github.com/Svahnar/svahnar-python/compare/v1.2.0...v1.3.0)

### Features

* **api:** api update ([#19](https://github.com/Svahnar/svahnar-python/issues/19)) ([bee3de4](https://github.com/Svahnar/svahnar-python/commit/bee3de4b0b283b6f2c42b464f1a373def1c94822))

## 1.2.0 (2025-04-09)

Full Changelog: [v1.1.0...v1.2.0](https://github.com/Svahnar/svahnar-python/compare/v1.1.0...v1.2.0)

### Features

* **api:** api update ([#14](https://github.com/Svahnar/svahnar-python/issues/14)) ([725168b](https://github.com/Svahnar/svahnar-python/commit/725168ba76812111a3d9713a437cb84ec32928c4))
* **api:** api update ([#18](https://github.com/Svahnar/svahnar-python/issues/18)) ([8f0719b](https://github.com/Svahnar/svahnar-python/commit/8f0719b187e3170b69a5927035cfd45cb86edd8e))
* **api:** manual updates ([#10](https://github.com/Svahnar/svahnar-python/issues/10)) ([3e61e54](https://github.com/Svahnar/svahnar-python/commit/3e61e54fc866fc4e9e995020c193657261b040f0))
* **api:** update via SDK Studio ([#5](https://github.com/Svahnar/svahnar-python/issues/5)) ([9adb118](https://github.com/Svahnar/svahnar-python/commit/9adb118b93546daab171919e7e05fba56e7cfdcd))


### Chores

* fix typos ([#8](https://github.com/Svahnar/svahnar-python/issues/8)) ([a23c194](https://github.com/Svahnar/svahnar-python/commit/a23c194a27c3b1e0c63ed66cf3cc52b7d3f84b2a))
* go live ([#1](https://github.com/Svahnar/svahnar-python/issues/1)) ([ec7ee3c](https://github.com/Svahnar/svahnar-python/commit/ec7ee3cffa0c4f3c5175c311a88079c31b2a29a8))
* **internal:** remove trailing character ([#12](https://github.com/Svahnar/svahnar-python/issues/12)) ([7c12256](https://github.com/Svahnar/svahnar-python/commit/7c12256d67a176fb25f1f3d3f6e7923eeb65c077))
* **internal:** slight transform perf improvement ([#15](https://github.com/Svahnar/svahnar-python/issues/15)) ([1fb0d08](https://github.com/Svahnar/svahnar-python/commit/1fb0d0840818f980c70c7fe07f6b6130ae51f983))
* slight wording improvement in README ([#17](https://github.com/Svahnar/svahnar-python/issues/17)) ([d2178f2](https://github.com/Svahnar/svahnar-python/commit/d2178f220907a4faf582a06f809d0e6434639c94))
* sync repo ([8508d3c](https://github.com/Svahnar/svahnar-python/commit/8508d3cc6cff7e92695af5b35a08ea06eabd1e13))
* update SDK settings ([#3](https://github.com/Svahnar/svahnar-python/issues/3)) ([be2bc47](https://github.com/Svahnar/svahnar-python/commit/be2bc47c168157dca68cb92686fbafcc584d8f6a))

## 1.1.0 (2025-04-08)

Full Changelog: [v1.0.0...v1.1.0](https://github.com/Svahnar/svahnar-python/compare/v1.0.0...v1.1.0)

### Features

* **api:** api update ([#14](https://github.com/Svahnar/svahnar-python/issues/14)) ([725168b](https://github.com/Svahnar/svahnar-python/commit/725168ba76812111a3d9713a437cb84ec32928c4))


### Chores

* **internal:** remove trailing character ([#12](https://github.com/Svahnar/svahnar-python/issues/12)) ([7c12256](https://github.com/Svahnar/svahnar-python/commit/7c12256d67a176fb25f1f3d3f6e7923eeb65c077))

## 1.0.0 (2025-03-30)

Full Changelog: [v0.1.0-alpha.1...v1.0.0](https://github.com/Svahnar/svahnar-python/compare/v0.1.0-alpha.1...v1.0.0)

### Features

* **api:** manual updates ([#10](https://github.com/Svahnar/svahnar-python/issues/10)) ([3e61e54](https://github.com/Svahnar/svahnar-python/commit/3e61e54fc866fc4e9e995020c193657261b040f0))


### Chores

* fix typos ([#8](https://github.com/Svahnar/svahnar-python/issues/8)) ([a23c194](https://github.com/Svahnar/svahnar-python/commit/a23c194a27c3b1e0c63ed66cf3cc52b7d3f84b2a))

## 0.1.0-alpha.1 (2025-03-26)

Full Changelog: [v0.0.1-alpha.1...v0.1.0-alpha.1](https://github.com/Svahnar/svahnar-python/compare/v0.0.1-alpha.1...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([#5](https://github.com/Svahnar/svahnar-python/issues/5)) ([9adb118](https://github.com/Svahnar/svahnar-python/commit/9adb118b93546daab171919e7e05fba56e7cfdcd))

## 0.0.1-alpha.1 (2025-03-26)

Full Changelog: [v0.0.1-alpha.0...v0.0.1-alpha.1](https://github.com/Svahnar/svahnar-python/compare/v0.0.1-alpha.0...v0.0.1-alpha.1)

### Chores

* go live ([#1](https://github.com/Svahnar/svahnar-python/issues/1)) ([ec7ee3c](https://github.com/Svahnar/svahnar-python/commit/ec7ee3cffa0c4f3c5175c311a88079c31b2a29a8))
* sync repo ([8508d3c](https://github.com/Svahnar/svahnar-python/commit/8508d3cc6cff7e92695af5b35a08ea06eabd1e13))
* update SDK settings ([#3](https://github.com/Svahnar/svahnar-python/issues/3)) ([be2bc47](https://github.com/Svahnar/svahnar-python/commit/be2bc47c168157dca68cb92686fbafcc584d8f6a))
